@@ -1,10 +1,12 @@
-#!/usr/bin/perl
-
 package Devel::REPL::Plugin::CompletionDriver::Turtles;
 use Devel::REPL::Plugin;
-
 use namespace::clean -except => [ "meta" ];
 
+sub BEFORE_PLUGIN {
+    my $self = shift;
+    $self->load_plugin('Completion');
+}
+
 around complete => sub {
   my $orig = shift;
   my ($self, $text, $document) = @_;
@@ -22,8 +24,8 @@ around complete => sub {
         map { "$pre$_" }
         grep { $_ =~ $filter }
         map { /^expr?_command_(\w+)/ ? $1 : () }
-        map { $_->{name} }
-        $self->meta->compute_all_applicable_methods
+        map { $_->name }
+        $self->meta->get_all_methods
       ),
     );
   } else {
