@@ -30,6 +30,20 @@ __END__
 
 Devel::REPL::Plugin::Timing - display execution times
 
+=head1 SYNOPSIS
+
+ # in your re.pl file:
+ use Devel::REPL;
+ my $repl = Devel::REPL->new;
+ $repl->load_plugin('Timing');
+
+ # after you run re.pl:
+ $ sum map $_*100, 1..100000;
+ Took 0.0830280780792236 seconds.
+ 500005000000
+
+ $
+
 =head1 AUTHOR
 
 Shawn M Moore, C<< <sartak at gmail dot com> >>
